@@ -114,6 +114,10 @@ def emits_deprecation(*messages):
 
         Note: requires Python 2.6 or later
     """
+    # DeprecationWarning is no longer loud by default in PY 2.7
+    # we need to make it loud for @emits_deprecation below
+    warnings.filterwarnings("default", category=DeprecationWarning)
+
     @decorator
     def decorate(fn, *args, **kw):
         if sys.version_info < (2, 6):
@@ -126,11 +130,11 @@ def emits_deprecation(*messages):
                 assert m is not None, 'No message to match warning: %s' % w.message
                 assert w is not None, 'No warning to match message #%s: %s' % (count, m)
                 assert issubclass(w.category, DeprecationWarning), 'DeprecationWarning not emitted, got %s type instead' % w.category
-                assert re.search(m, str(w.message)), 'Message regex "%s" did not match %s' % (m, w.message)
+                assert re.search(m, str(w.message)), 'Message regex "%s" did not match "%s"' % (m, w.message)
             return retval
     return decorate
 
-def raises(arg1, arg2=None, re_esc=True):
+def raises(arg1, arg2=None, re_esc=True, **kwargs):
     """
         Decorate a test encorcing it emits the given Exception and message
         regex.
@@ -170,6 +174,13 @@ def raises(arg1, arg2=None, re_esc=True):
                 raise
             if msgregex is not None and not re.search(msgregex, str(e)):
                 raise
+            for attrname, msg in kwargs.iteritems():
+                if not hasattr(e, attrname):
+                    print '@raises: exception missing "{0}" attribute'.format(attrname)
+                    raise
+                if getattr(e, attrname) != msg:
+                    raise
+
     return decorate
 
 def assert_equal_sql(sql, correct_sql):
